@@ -1,11 +1,11 @@
 
-#include "stdlib.h"            /* Standard Includes                          */
+#include "stdlib.h"      /* Standard Includes                                */
 #include "stdio.h"
-
-#define MFI_INIT 1
-#include "addermfx.h"          /* Get MFX Data Structure                     */
-#include "xbmfx.c"             /* Get Lowlevel Routines for MFX Read/Write   */
-#include "addermfx.c"          /* Ret Read and Write MFX Routines            */
+#include "addermfx.h"    /* MFX Data Structure "mfi" Definitions (P) by XBW  */
+#include "xbmfx.c"       /* MFX read/write routines; contributed by XBW      */
+#include "addermfx.c"    /* Get Read and Write MFX Routines; (P) by XbW      */
+ 
+MFI mfi;                 /* Data Structure for Communication with XbW        */
  
 main(){
   ReadMFXGroup_mfi(0,0);       /* Data Input Section                         */
