@@ -1,5 +1,5 @@
 
 #define MFX_INIT 1
 
-#include "test.mfx.h"
+#include "testmfx.h"
 
