@@ -1,4 +1,4 @@
- 
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
 /*                                                                           */
@@ -268,6 +268,7 @@ int  XbWFOb_epO(char *name){
           if (XbWFOb_GetPar(&XbWVWd_W,&XbWVOb_O,mf_n,XbWDOb_GtAllP|XbWDOb_GetAnO) != NULL){
             XbWVEd_nxt = Vor;
             XbWFOj_DiEdContents(&XbWVWd_W,&XbWVOb_O,1);
+            if (XbWVEd_nxt == EndInput) { return(0); };
             if (XbWVEd_nxt == CursorUp) {
               XbWFOb_epO((char*)XbWVOb_O.onm);
               };
@@ -446,6 +447,7 @@ int  XbWFOb_eqO(XbWDDb_DbIObj  *MOB){
   if ((mf_n = (char*)XbWFDb_VarInh(MOB->chn,XbWDDb_FPtr,"rqC",0)) != NULL) {
     XbWFMf_RdCompMak(XbWVDb_ActGrp2);
     };
+  if (XbWVEd_nxt == EndInput) { return(0); };
   if (XbWVEd_nxt != CursorUp) {
     for (ii=0;ii<100;ii++){
       if (XbWVEd_nxt != EndInput) {
@@ -453,12 +455,10 @@ int  XbWFOb_eqO(XbWDDb_DbIObj  *MOB){
         if ((mf_n = (char*)XbWFDb_VarInh(MOB->chn,XbWDDb_Str,sstr,1)) != NULL) {
           XbWVEd_nxt = Vor;
           XbWFOb_EdDpObj(mf_n,1);
+          if (XbWVEd_nxt == EndInput) { return(0); };
           if (XbWVEd_nxt == CursorUp) {
             XbWFOb_epO(mf_n);
             };
-          if (XbWVEd_nxt == EndInput) {
-            ii = 110;
-            };
           }
         else {
           ii = 110;
@@ -757,6 +757,7 @@ void  XbWFOb_EdObjMausPos(
     XbWFOb_GetPar(WI,&MOB,vfname,XbWDOb_GtAllP|XbWDOb_GetAnO);
     XbWVEd_nxt = Vor;
     XbWFOj_DiEdContents(WI,&MOB,1);
+    if (XbWVEd_nxt == EndInput) { return; };
     if (XbWVEd_nxt == CursorUp) {
       XbWFOb_epO((char*)MOB.onm);
       };
@@ -770,6 +771,7 @@ void  XbWFOb_EdObjMausPos(
         if ((obn = (char*)XbWFDb_VarInh(MOB.chn,XbWDDb_Str,sstr,1)) != NULL) {
           XbWVEd_nxt = Vor;
           XbWFOb_EdDpObj(obn,1);
+          if (XbWVEd_nxt == EndInput) { return; };
           if (XbWVEd_nxt == CursorUp) {
             XbWFOb_epO(obn);
             };
@@ -817,6 +819,7 @@ int  XbWFOb_EditAndDisp(char *obn,int mode){
         XbWFOb_GetPar(&XbWVWd_W,&MOB,(char*)MOB.onm,XbWDOb_GtAllP|XbWDOb_GetAnO);
         XbWVEd_nxt = Vor;
         XbWFOj_DiEdContents(&XbWVWd_W,&MOB,1);
+        if (XbWVEd_nxt == EndInput) { return(0); };
         if (XbWVEd_nxt == CursorUp) {
           XbWFOb_epO((char*)MOB.onm);
           };
@@ -831,6 +834,7 @@ int  XbWFOb_EditAndDisp(char *obn,int mode){
             if ((obn = (char*)XbWFDb_VarInh(MOB.chn,XbWDDb_Str,sstr,1)) != NULL) {
               XbWVEd_nxt = Vor;
               XbWFOb_EdDpObj(obn,1);
+              if (XbWVEd_nxt == EndInput) { return(0); };
               if (XbWVEd_nxt == CursorUp) {
                 XbWFOb_epO(obn);
                 };
@@ -1650,30 +1654,37 @@ void  XbWFOj_SpawnTsk(XbWDDb_DbIWdw  *TW,XbWDDb_DbIObj  *TO,
   };
 
 /*}}}  */
-
+ 
 /*{{{  XbWFOj_EdCyc(       ***      Zyklisches Objekt editieren*/
 void  XbWFOj_EdCyc(XbWDDb_DbIObj  *TO){
   char * text;
   int thedef;
   char *textstr;
+  int theoffset=0;
   char sstr[30];
  
   text = XbWFDb_VarInh(TO->chn,XbWDDb_Str,"V",1);
-  thedef = XbWFDb_GetNum(TO->chn,"v",1);
-  thedef++;
+  if (text==NULL){
+    return;
+    }
+  theoffset = XbWFDb_GetNum(TO->chn,"m",1);
+  thedef = XbWFDb_GetNum(TO->chn,"v",1) +1 - theoffset;
+ 
   sprintf(sstr,"Text%d",thedef);
  
   textstr = (char*)XbWFDb_VarInh(TO->chn,XbWDDb_Str,sstr,1);
   if (textstr == NULL){
-    textstr = XbWFDb_VarInh(TO->chn,XbWDDb_Str,"Text-1",1);
+    thedef=0;
+    textstr = XbWFDb_VarInh(TO->chn,XbWDDb_Str,"Text0",1);
     if (textstr == NULL){
-      textstr = "";
+      strcpy(text,"");
+      XbWFDb_PutNum(TO->chn,"v",1,0);
+      return;
       };
-    thedef = -1;
     };
-
+ 
   strcpy(text,textstr);
-  XbWFDb_PutNum(TO->chn,"v",1,thedef);
+  XbWFDb_PutNum(TO->chn,"v",1,thedef+theoffset);
   };
 
 /*}}}  */
@@ -1681,25 +1692,67 @@ void  XbWFOj_EdCyc(XbWDDb_DbIObj  *TO){
 void  XbWFOj_DpCyc(XbWDDb_DbIObj  *TO){
   char * text;
   int thedef;
+  int theoffset=0;
   char *textstr;
   char sstr[30];
  
   text = XbWFDb_VarInh(TO->chn,XbWDDb_Str,"V",1);
+  if (text==NULL){ return; };
+  theoffset = XbWFDb_GetNum(TO->chn,"m",1);
   thedef = XbWFDb_GetNum(TO->chn,"v",1);
-/*   thedef++;  weglassen: der Unterschied zu EdCyc! */
+ 
+ 
+  if ( (thedef == -1) || ((thedef - theoffset) == -1) ){
+    int ii;
+    for (ii=0;ii>=0;ii++){
+      sprintf(sstr,"Text%d",ii);
+      textstr = (char*)XbWFDb_VarInh(TO->chn,XbWDDb_Str,sstr,1);
+      if (textstr == NULL){
+        if (ii>0){
+          textstr = (char*)XbWFDb_VarInh(TO->chn,XbWDDb_Str,"Text0",1);
+          strcpy(text,textstr);
+          XbWFDb_PutNum(TO->chn,"v",1,theoffset);
+          return;
+          };
+        strcpy(text,"");
+        XbWFDb_PutNum(TO->chn,"v",1,theoffset);
+        return;
+        };
+      if (strcmp(textstr,text)==0){
+        thedef = ii;
+        strcpy(text,textstr);
+        XbWFDb_PutNum(TO->chn,"v",1,ii+theoffset);
+        return;
+        };
+      };
+    };
+ 
+  thedef = thedef - theoffset;
+ 
   sprintf(sstr,"Text%d",thedef);
  
   textstr = (char*)XbWFDb_VarInh(TO->chn,XbWDDb_Str,sstr,1);
   if (textstr == NULL){
-    textstr = XbWFDb_VarInh(TO->chn,XbWDDb_Str,"Text-1",1);
+    XbWFDb_PutNum(TO->chn,"v",1,theoffset);
+    textstr = XbWFDb_VarInh(TO->chn,XbWDDb_Str,"Text0",1);
     if (textstr == NULL){
-      textstr = "";
+      strcpy(text,"");
+      XbWFDb_PutNum(TO->chn,"v",1,-1);
+      return;
       };
-    thedef = -1;
     };
-
+ 
   strcpy(text,textstr);
-/*   XbWFDb_PutNum(TO->chn,"v",1,thedef); weglassen. s.o. */
+ 
+  if (textstr == NULL) {return; };
+  if (!thedef){
+    XbWSGr_TLBox(XbWVOb_X,XbWVOb_Y,XbWVOb_x,XbWVOb_y,textstr,
+      *TO->bkc,*TO->txc,*TO->bfc);
+    }
+  else {
+    XbWSGr_TLBox(XbWVOb_X,XbWVOb_Y,XbWVOb_x,XbWVOb_y,textstr,
+      *TO->dfc,*TO->txc,*TO->bfc);
+    }
   };
 
 /*}}}  */
@@ -1716,7 +1769,6 @@ int  XbWFOj_Ed_Y(int edit, XbWDDb_DbIObj  *TOB){
 int  XbWFOj_Dp_Y(XbWDDb_DbIObj  *TOB){
   XbWSGr_TLBox(XbWVOb_X,XbWVOb_Y,XbWVOb_x,XbWVOb_y,NULL,XbWVGr_White,0,XbWVGr_LRed);
   XbWFOj_DpCyc(TOB);
-  XbWFOj_Dp_S(TOB);
   return(1);
   };
 
@@ -1824,7 +1876,8 @@ double  XbWFOj_GetNum(XbWDDb_DbIObj  *TO){
       strcat(tx,ttx);
       }
     else {
-      strcat(tx,teha);
+      strcat(tx,
+        (char*)XbWFTb_PckTxt(teha));
       };
     };
   strcpy(XbWVOb_GTxt,tx);
@@ -2286,11 +2339,15 @@ int  XbWFOj_Ed_A(int edit, XbWDDb_DbIObj  *TOB, int this_obj){
   aof = (int)  XbWFDb_GetNum(TOB->chn,"ao",1);
 
   if (!this_obj){
-    gr_st = XbWFDb_FindGrp("OBX","act");
-    if (gr_st == NULL) { return(0); };
-    agr = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"aln",1);
-    aon = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"agn",1);
-
+    agr = (char*)XbWFDb_VarInh(TOB->chn,XbWDDb_Str,"aln",1);
+    aon = (char*)XbWFDb_VarInh(TOB->chn,XbWDDb_Str,"agn",1);
+ 
+    if((agr==NULL) || (aon==NULL)){
+      gr_st = XbWFDb_FindGrp("OBX","act");
+      if (gr_st == NULL) { return(0); };
+      agr = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"aln",1);
+      aon = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"agn",1);
+      };
     if ((ao_st = XbWFDb_FindGrp(agr,aon)) == NULL) { return(0); };
 
     }
@@ -2517,50 +2574,15 @@ int  XbWFGr_MaxY(void){
 /*}}}  */
 /*{{{  XbWFGr_TWidth(      ***      Pixelbreite eines Strings ermitteln*/
 int  XbWFGr_TWidth(char *sstr){
-  XbWDDb_DbIVar  *sv_gp;
   int cx=11;
-  if (XbWVWd_Wdt == 0) {
-    sv_gp = XbWFDb_FindGrp("SVR","video");
-    if (sv_gp != NULL){
-      cx = (int)XbWFDb_GetNum(sv_gp,"CharX",1);
-      if (cx == 0){
-        cx = 8;
-        }
-      else {
-        XbWVWd_Wdt = cx;
-        };
-      };
-    }
-  else {
-    cx = XbWVWd_Wdt;
-    };
+  cx = XbWVWd_Wdt;
   return(cx*strlen(sstr));
   };
 /*}}}  */
 /*{{{  XbWFGr_THeight(     ***      Pixelhoehe eines Zeichens ermitteln*/
 int  XbWFGr_THeight(void){
-  XbWDDb_DbIVar  *sv_gp;
   int cy=8;
-  if (XbWVWd_Hgt == 0){
-    if (XbWVDb_DbkStrt != NULL){
-      sv_gp = XbWFDb_FindGrp("SVR","video");
-      if (sv_gp != NULL){
-        cy = (int)XbWFDb_GetNum(sv_gp,"CharY",1);
-        if (cy == 0){
-          cy = 12;
-          }
-        else {
-          XbWVWd_Hgt = cy;
-          };
-        };
-      }
-    else {
-      cy = 12;
-      };
-    }
-  else {
-    cy = XbWVWd_Hgt;
-    };
+  cy = XbWVWd_Hgt;
   return(cy);
   };
 /*}}}  */
