@@ -1,4 +1,3 @@
- 
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /*                                                                           */
@@ -12,6 +11,10 @@
 /* Header--------------------------------------------------------------------*/
  
 #include "xbw.h"
+#include "signal.h"
+/*{{{F xbw.h*/
+/*:::F xbw.h*/
+/*}}}  */
 
 /*  ---------------------Compiler-Modelle------------------------------------*/
                       /* ---............Nicht mglich  */
@@ -234,13 +237,15 @@ void  XbWFWd_DrawAll(void){
       XbWVWd_W = XbWVWd_LastDsp;
       };
     };
-  if (((*XbWVWd_W.icn) ) == 0) {
-    for (count = 1;count <= XbWDWd_MaxWdw;count++) {
-      if (XbWFWd_GetPara(count, &MPW)) {
-        if (((*XbWVWd_W.icn) ) == 0) {
-          if (XbWFTb_CmpStr((char*)XbWVWd_W.nm,(char*)MPW.nm) != 0) {
-            XbWFWd_OvrLap(&MPW,&XbWVWd_W);
-            XbWFWd_Hide(&MPW,&XbWVWd_W);
+  if (XbWVWd_W.icn != NULL){
+    if (((*XbWVWd_W.icn) ) == 0) {
+      for (count = 1;count <= XbWDWd_MaxWdw;count++) {
+        if (XbWFWd_GetPara(count, &MPW)) {
+          if (((*XbWVWd_W.icn) ) == 0) {
+            if (XbWFTb_CmpStr((char*)XbWVWd_W.nm,(char*)MPW.nm) != 0) {
+              XbWFWd_OvrLap(&MPW,&XbWVWd_W);
+              XbWFWd_Hide(&MPW,&XbWVWd_W);
+              };
             };
           };
         };
@@ -605,13 +610,15 @@ void  XbWFWd_LockOFF(void){
   };
 /*}}}  */
 /*{{{  XbWFWd_ChkDisp(     ***    Check ob Hintergrund-Display von Wdws noetig*/
-void  XbWFWd_ChkDisp(void){
+void  XbWFWd_ChkDisp(int sofort){
   XbWDDb_DbIWdw MPW;
   time_t ntime;
   char anam[20];
   if (XbWVWd_Time > 0) {
     ntime = XbWVSy_Time;
-    if (ntime <= XbWVWd_Time+3) { return; };
+    if (ntime <= XbWVWd_Time+3) {
+      if (!sofort) return;
+      };
     XbWVWd_Time = 0;
     };
   strcpy(anam,(char*)XbWVWd_W.nm);
@@ -671,35 +678,20 @@ void  XbWFWd_ChkDisp(void){
   };
 /*}}}  */
 /*{{{  XbWFWd_ChkAct(      ***    Check auf Hintergrund-Aktion von Objekten*/
-void  XbWFWd_ChkAct(void){
+void  XbWFWd_ChkAct(int sofort){
   time_t ntime;
   char sstr[40];
   int ii;
-  int suchnummer=0;
+  /*int suchnummer=0;*/
   XbWDDb_DbIVar  *sv_gp;
-
+ 
   ntime = XbWVSy_Time;
-  if (ntime == XbWVSy_AltChkActTime){ return;};
+  if (ntime <= XbWVSy_AltChkActTime+2){
+    if(!sofort)return;
+    };
   XbWVSy_AltChkActTime = ntime;
-  if ((ntime & 0x0003) != 0){ return; };
-
-  if  ((suchnummer=(ntime & 0x1FFF))==0x1000) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x0FFF))==0x0800) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x07FF))==0x0400) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x03FF))==0x0200) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x01FF))==0x0100) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x00FF))==0x0080) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x007F))==0x0040) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x003F))==0x0020) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x001F))==0x0010) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x000F))==0x0008) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x0007))==0x0004) {goto start_edit;};
-  if  ((suchnummer=(ntime & 0x0003))==0x0000) {suchnummer = 2; goto start_edit;};
-  return;
-  start_edit:;
-
-  sprintf(sstr,"ed_obj%d",suchnummer);
-  sv_gp = XbWFDb_FindGrp("SVR",sstr);
+ 
+  sv_gp = XbWFDb_FindGrp("SVR","ed_obj");
   if (sv_gp != NULL){
     char *obj_nam;
     ii=0;
@@ -709,7 +701,7 @@ void  XbWFWd_ChkAct(void){
       if (sv_gp != NULL){
         char *wdwname;
         wdwname = (char*)XbWFDb_VarInh(sv_gp,XbWDDb_Str,"W",1);
-        XbWFWd_SwitchTo(wdwname,48);
+        XbWFWd_SwitchTo(wdwname,0);
         XbWFOb_EditAndDisp(obj_nam,1);
         };
       ii++;
@@ -748,12 +740,21 @@ void  XbWFWd_OManager(int popup, char *wname){
         XbWVMs_RButt = 0;
         XbWVMs_MButt = 0;
         XbWVMs_Button = 0;
-        XNextEvent(XbWVSy_ConTxt.dpy, &event);
         XbWVSy_Time = XbWSSy_TimeSec();
-        if (! *XbWVWd_W.wfx ) {
-          XbWFWd_ChkAct();
-          XbWFWd_ChkDisp();
+        while(1){
+          if (XCheckTypedWindowEvent(XbWVSy_ConTxt.dpy,XbWVSy_ConTxt.window,Expose,&event)) break;
+          if (XCheckTypedWindowEvent(XbWVSy_ConTxt.dpy,XbWVSy_ConTxt.window,EnterNotify,&event)) break;
+          if (XCheckTypedWindowEvent(XbWVSy_ConTxt.dpy,XbWVSy_ConTxt.window,MotionNotify,&event)) break;
+          if (XCheckTypedWindowEvent(XbWVSy_ConTxt.dpy,XbWVSy_ConTxt.window,KeyPress,&event)) break;
+          if (XCheckTypedWindowEvent(XbWVSy_ConTxt.dpy,XbWVSy_ConTxt.window,ButtonPress,&event)) break;
+          XbWVSy_Time = XbWSSy_TimeSec();
+          usleep(30000);
+          if (! *XbWVWd_W.wfx ) {
+            XbWFWd_ChkAct(0);
+            };
           };
+        XbWVSy_Time = XbWSSy_TimeSec();
+        XbWVSy_AltChkActTime=XbWVSy_Time;
         switch(event.type){
           case Expose:
             if (lastexpose < (neuexpose=XbWSSy_TimeSec()) ){
@@ -822,41 +823,46 @@ void  XbWFWd_OManager(int popup, char *wname){
     XbW_OManagerWeiter:;
 #endif
  
-    if ( *XbWVWd_W.wfx ) {
-      if (!XbWFTb_InBox(XbWVMs_XPos,XbWVMs_YPos,
-          *XbWVWd_W.nx,*XbWVWd_W.ny,
-          *XbWVWd_W.nx+*XbWVWd_W.sx,*XbWVWd_W.ny+*XbWVWd_W.sy)) {
-        /* XbWSMs_SetStopCursor();*/
-        if (warn_state != 1){
-          XbWFTb_Warning("Please quit the active window explicitly!");
-          warn_state = 1;
+    if (XbWVWd_W.wfx != NULL) {
+      /*{{{  */
+      if ( *XbWVWd_W.wfx ) {
+        if (!XbWFTb_InBox(XbWVMs_XPos,XbWVMs_YPos,
+            *XbWVWd_W.nx,*XbWVWd_W.ny,
+            *XbWVWd_W.nx+*XbWVWd_W.sx,*XbWVWd_W.ny+*XbWVWd_W.sy)) {
+          /* XbWSMs_SetStopCursor();*/
+          if (warn_state != 1){
+            XbWFTb_Warning("Please quit the active window explicitly!");
+            warn_state = 1;
+            };
+          }
+        else  {
+          XbWSMs_SetArrowCursor();
+          if (warn_state != 2){
+            XbWFTb_Message("XbW - Multiwindow Dialogmanager.");
+            warn_state = 2;
+            };
           };
         }
-      else  {
-        XbWSMs_SetArrowCursor();
-        if (warn_state != 2){
-          XbWFTb_Message("XbW - Multiwindow Dialogmanager.");
-          warn_state = 2;
+      else {
+        if (XbWVMs_PtrActualPtr != XbWVMs_PtrPtrArrow){
+          XbWSMs_SetArrowCursor();
           };
         };
+      
+      if (popup) {
+        if (! *XbWVWd_W.wfx ) {
+          XbWFGr_CurOFF();
+          XbWFWd_RestImage(&XbWVWd_W);
+          if (MPW.nm != NULL){
+            XbWFWd_SwitchTo((char*)MPW.nm,0);
+            };
+          XbWFGr_CurON();
+          return;
+          };
+        };
+      /*}}}  */
       }
-    else {
-      if (XbWVMs_PtrActualPtr != XbWVMs_PtrPtrArrow){
-        XbWSMs_SetArrowCursor();
-        };
-      };
-
-    if (popup) {
-      if (! *XbWVWd_W.wfx ) {
-        XbWFGr_CurOFF();
-        XbWFWd_RestImage(&XbWVWd_W);
-        if (MPW.nm != NULL){
-          XbWFWd_SwitchTo((char*)MPW.nm,0);
-          };
-        XbWFGr_CurON();
-        return;
-        };
-      };
+ 
     if (XbWVSy_ConTxt.is_a_key_waiting){
       while (!XbWSMs_IsAKey(1)){;};
       XbWSMs_GetKey(&tastencode2,&tastencode1);
@@ -967,8 +973,8 @@ void  XbWFWd_OManager(int popup, char *wname){
     makro_beendet:;
     XbWVSy_Time = XbWSSy_TimeSec();
     if (! *XbWVWd_W.wfx ) {
-      XbWFWd_ChkAct();
-      XbWFWd_ChkDisp();
+      XbWFWd_ChkAct(0);
+      XbWFWd_ChkDisp(0);
       };
     if (XbWVMs_Bewegt==1)   {
       XbWFGr_CurOFF();
