@@ -8,7 +8,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 
-
 /* Header--------------------------------------------------------------------*/
 
 #include "xbw.h"
@@ -191,7 +190,7 @@ int  XbWFTb_MouseWarp(void  *(*p)[], int(*t)[]){
   };
 /*}}}  */
 
-/*{{{  XbWFDb_LoadFont(               X11    Wechsle Verzeichnis*/
+/*{{{  XbWFDb_LoadFont(               X11    Wechsle Font*/
 int  XbWFDb_LoadFont(void  *(*p)[],int (*t)[]){
   char fontname[200];
  
@@ -309,6 +308,7 @@ int  XbWFMf_ExComand(int no, int tfun){
     XbWDMf_ST_R(83,"RootWindow",  XbWSSy_RootWindow);
     XbWDMf_ST_R(84,"EditFile",    XbWFDb_OpenSys);
     XbWDMf_ST_R(85,"wdw",         XbWFDb_AppWdw);
+    XbWDMf_ST_R(86,"Exec",        XbWSOS_SpwnStd);
  
     default:
       switch(tfun) {
@@ -562,27 +562,35 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
   double *dinh;
   XbWDDb_DbIPtr *linh;
   char sstr[200];
-
-  XbWDDb_DbIVar  *gr_st;
+ 
+  static int normal_use=1;
+ 
+  XbWDDb_DbIVar  *gr_st=NULL;
   XbWDDb_DbIVar  *ao_st;
-
+ 
+  agr = (char*)XbWFDb_VarInh(TOB->chn,XbWDDb_Str,"aln",1);
+  aon = (char*)XbWFDb_VarInh(TOB->chn,XbWDDb_Str,"agn",1);
   anr = (int)  XbWFDb_GetNum(TOB->chn,"an",1);
   aof = (int)  XbWFDb_GetNum(TOB->chn,"ao",1);
 
   if (!this_obj){
-    if (aof == 0) {
+    if ( (1)|(aof == 0)) {        /* SPEEDUP CODE DISABLED! */
       static char aagr[100];
       static char aaon[100];
-      gr_st = XbWFDb_FindGrp("OBX","act");
-
-      if (gr_st == NULL) {
-        XbWVOb_mgr  = NULL;
-        XbWVOb_mao  = NULL;
-        return(0);
-        };
-
-      agr = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"aln",1);
-      aon = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"agn",1);
+ 
+      normal_use=1;
+      if((agr==NULL) || (aon==NULL)){
+        gr_st = XbWFDb_FindGrp("OBX","act");
+        if (gr_st == NULL) {
+          XbWVOb_mgr  = NULL;
+          XbWVOb_mao  = NULL;
+          return(0);
+          };
+ 
+        agr = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"aln",1);
+        aon = (char*)XbWFDb_VarInh(gr_st,XbWDDb_Str,"agn",1);
+        normal_use=0;
+        }
       strcpy(aagr,(char*)(XbWFTb_PckTxt(agr)));
       strcpy(aaon,(char*)(XbWFTb_PckTxt(aon)));
  
@@ -618,15 +626,15 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
     agr   = XbWVOb_agr;
     aon   = XbWVOb_aon;
     };
-
+ 
   strcpy(sstr,"");
 
   if (XbWFDb_GetInf(ao_st,anr+aof,aov,&atp,&ain,&ale,0)) {
-    if (!this_obj){ sprintf(sstr,"[%s] UNKNOWN TYPE",aov); }
+    if ((!this_obj)&(!normal_use)){ sprintf(sstr,"[%s] UNKNOWN TYPE",aov); }
     else { sprintf(sstr,"???"); };
     switch (atp) {
       case XbWDDb_Int: iinh = (int*)ain;
-                   if (!this_obj){
+                   if ((!this_obj)&(!normal_use)){
                      sprintf(sstr,"i(%s %d);",aov,*iinh);
                      }
                    else {
@@ -640,7 +648,7 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
                        ffmt = "%9.5f";
                        };
                      sprintf(sstr1,(char*)XbWFTb_PckTxt(ffmt),*dinh);
-                     if (!this_obj) {
+                     if ((!this_obj)&(!normal_use)) {
                        sprintf(sstr,"d(%s %s);",aov,sstr1);
                        }
                      else {
@@ -650,7 +658,7 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
                    XbWFDb_AddVARTypeDescription(sstr,aov);
                    break;
       case XbWDDb_Str:
-                   if (!this_obj){
+                   if ((!this_obj)&(!normal_use)){
                      sprintf(sstr,"s(%s %d (\"%s\"));",aov,ale,ain);
                      }
                    else { sprintf(sstr,"%s",ain); };
@@ -660,7 +668,7 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
                      char pstr[100];
                      linh = (XbWDDb_DbIPtr *)ain;
                      strcpy(pstr,(char*)XbWFDb_DbIToStr(*linh,XbWDDb_DbISys));
-                     if (!this_obj){
+                     if ((!this_obj)&(!normal_use)){
                        sprintf(sstr,"pn(%s (ptr)%s);",aov,pstr);
                        }
                      else { sprintf(sstr,"%s",pstr); };
@@ -671,7 +679,7 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
                      char pstr[100];
                      linh = (XbWDDb_DbIPtr *)ain;
                      strcpy(pstr,(char*)XbWFDb_DbIToStr(*linh,XbWDDb_DbISys));
-                     if (!this_obj){
+                     if ((!this_obj)&(!normal_use)){
                        sprintf(sstr," %s cont'd. at %s",aov,pstr);
                        }
                      else { sprintf(sstr,"%s",pstr); };
@@ -681,7 +689,7 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
                      char pstr[100];
                      linh = (XbWDDb_DbIPtr *)ain;
                      strcpy(pstr,(char*)XbWFDb_DbIToStr(*linh,XbWDDb_DbISys));
-                     if (!this_obj){
+                     if ((!this_obj)&(!normal_use)){
                        sprintf(sstr,"pn(%s (ptr)%s);",aov,pstr);
                        }
                      else { sprintf(sstr,"%s",pstr); };
@@ -691,7 +699,7 @@ int  XbWFOj_Dp_A(XbWDDb_DbIObj  *TOB, int this_obj){
                      char pstr[100];
                      linh = (XbWDDb_DbIPtr *)ain;
                      strcpy(pstr,(char*)XbWFDb_DbIToStr(*linh,XbWDDb_DbISys));
-                     if (!this_obj){
+                     if ((!this_obj)&(!normal_use)){
                        sprintf(sstr,"eg(); %s End of group; Pointer to %s (start of group)",aov,pstr);
                        }
                      else { sprintf(sstr,"%s",pstr); };
@@ -1003,8 +1011,8 @@ void  XbWFTb_PutError(void  *(*p)[]){
 /*}}}  */
 /*{{{  XbWFTb_Case(        ***   Case-Abfrage fuer Metafile-Interpreter*/
 int  XbWFTb_Case(void  *(*p)[],int (*t)[]){
-  double v1,v2;
-  char *s1,*s2;
+  double v1=0,v2=0;
+  char *s1="",*s2="";
   int is1string=0;
   int is2string=0;
   char *oper;
@@ -1176,11 +1184,20 @@ int  XbWFTb_AnswerPopUpReq(void  *(*p)[]){
     (char*)(*p)[4],
     (char*)(*p)[5]);
   switch(ii) {
-    case 1:  XbWFMf_ReadMakro((char*)(*p)[6]); return(0);
-    case 2:  XbWFMf_ReadMakro((char*)(*p)[7]); return(0);
-    case 3:  XbWFMf_ReadMakro((char*)(*p)[8]); return(0);
+    case 1:  if (strlen( (char*)(*p)[6])) {
+               XbWFMf_ReadMakro((char*)(*p)[6]);
+               }
+               return(0);
+    case 2:  if (strlen( (char*)(*p)[6])) {
+               XbWFMf_ReadMakro((char*)(*p)[7]);
+               return(0);
+               }
+    case 3:  if (strlen( (char*)(*p)[6])) {
+               XbWFMf_ReadMakro((char*)(*p)[8]);
+               return(0);
+               }
     };
-  return(1);
+  return(0);
   };
 /*}}}  */
 /*{{{  XbWFTb_DbgMta(      ***   Debugging fuer Metafiles einschalten*/
