@@ -1,4 +1,7 @@
- 
+/*{{{F xbwparser.y*/
+/*:::F xbwparser.y*/
+/*}}}  */
+
 struct symrec {
   char *name;
   int type;
@@ -32,6 +35,7 @@ int put_lval_if(void);
 int put_lval_then(void);
 int put_lval_num_macropar(int num);
 int put_lval_num_macropar(int num);
+int put_lval_str_macropar(int num);
 int put_lval_nullptr(void);
 
 symrec *getsym(char *sym_name);
