@@ -1652,10 +1652,10 @@ void
 void   XbWFWd_BackGr(void);
 /*}}}  */
 /*{{{  XbWFWd_ChkAct( [x3.c;0598]       ***    Check auf Hintergrund-Aktion von Objekten*/
-void  XbWFWd_ChkAct(void);
+void  XbWFWd_ChkAct(int sofort);
 /*}}}  */
 /*{{{  XbWFWd_ChkDisp( [x3.c;0532]      ***    Check ob Hintergrund-Display von Wdws noetig*/
-void  XbWFWd_ChkDisp(void);
+void  XbWFWd_ChkDisp(int sofort);
 /*}}}  */
 /*{{{  XbWFWd_Draw( [x3.c;0361]         ***    Neuzeichnen (???)*/
 void  XbWFWd_DrawAll(void);
@@ -2347,5 +2347,7 @@ void  XbWFMf_StartMF(char *filename);
 int  XbWSSy_SubWindow(int x, int y, int sx, int sy);
 void XbWFSy_bf_printf(char *a, char *b);
 int  XbWFDb_AppDblVal(void  *(*p)[], double val);
-
+int XbWSSy_LoadFont(char *fontname);
+int  XbWFDb_InsertObj(void  *(*p)[], int (*t)[]);
+int  XbWFDb_LoadFont(void  *(*p)[],int (*t)[]);
 
